/*
** Copyright 1998 - 1999 Double Precision, Inc.
** See COPYING for distribution information.
*/


/* Whether we search the "alias" account */
#undef	ALIAS

/* Whether we issue explicit fsync calls for message delivery */
#undef	EXPLICITSYNC

/* Whether we implement user-extension addressing */
#undef	LOCAL_EXTENSIONS

/* Allow mail delivery to root */
#undef	ALLOW_ROOT

#undef	NAME

#undef	testmode
